@@ -4,6 +4,6 @@ from dataclasses import dataclass
 @dataclass
 class DiversityFilterParameters:
     name: str
-    minscore: float
-    bucket_size: int
-    minsimilarity: float
+    minscore: float = 0.4
+    bucket_size: int = 25
+    minsimilarity: float = 0.4
