@@ -43,6 +43,25 @@ class ComponentSpecificParametersEnum:
     __ION_CLASS = "Ion class"
     __CONTAINER_TYPE = "container_type"
 
+    __SMILES = "smiles"
+    __MODEL_PATH = "model_path"
+
+    @property
+    def MODEL_PATH(self):
+        return self.__MODEL_PATH
+
+    @MODEL_PATH.setter
+    def MODEL_PATH(self, value):
+        raise ValueError("Do not assign value to a ComponentSpecificParametersEnum field")
+
+    @property
+    def SMILES(self):
+        return self.__SMILES
+
+    @SMILES.setter
+    def SMILES(self, value):
+        raise ValueError("Do not assign value to a ComponentSpecificParametersEnum field")
+
     @property
     def CONTAINER_TYPE(self):
         return self.__CONTAINER_TYPE
