@@ -22,6 +22,11 @@ class ScoringFunctionComponentNameEnum:
     TOTAL_SCORE = "total_score" # there is no actual component corresponding to this type
     REACTION_FILTERS = "reaction_filters"
 
+    # Link invent specific
+    LINKER_EFFECTIVE_LENGTH = "linker_effective_length"
+    LINKER_GRAPH_LENGTH = "linker_graph_length"
+    LINKER_LENGTH_RATIO = "linker_length_ratio"
+
     #NOTE: components below are AZ specific
     AZ_LOGD74 = "az_logd74"
     HLM_CLINT = "hlm_clint"
