@@ -29,14 +29,3 @@ class BaseROCSComponent(BaseScoreComponent):
     @abstractmethod
     def _calculate_omega_score(self, smiles, step) -> np.array:
         raise NotImplementedError("_calculate_omega_score method is not implemented")
-
-    def _assign_id(self):
-        '''
-        This is a temp solution until the id=step is passed to this class
-        '''
-        all_files = glob.glob(os.path.join(self.dir_name, self.overlay_prefix+'*'+'.sdf'))
-        if len(all_files) == 0:
-            return
-        all_files = list(map(os.path.basename, all_files))
-        old_ids = list(map(int, [re.findall(r'(\d{4})\.sdf$', f)[0] for f in all_files]))
-        self.id = max(old_ids) + 1
\ No newline at end of file
