@@ -7,7 +7,8 @@ from reinvent_scoring.scoring.score_components import TanimotoSimilarity, \
     SASComponent, MolWeight, PSA, RotatableBonds, HBD_Lipinski, HBA_Lipinski, \
     NumRings, AZlogD74, HLMClint, SlogP, \
     RHClint, HHClint, SolubilityDD, HERG, CACO2Intrinsic, CACO2Efflux, AZdock, RatPKPiP, Top20, GraphLength, \
-    NumberOfStereoCenters
+    NumberOfStereoCenters,\
+    LinkerLengthRatio, LinkerGraphLength, LinkerEffectiveLength
 from reinvent_scoring.scoring.score_components import BaseScoreComponent
 from reinvent_scoring.scoring.enums import ScoringFunctionComponentNameEnum
 from reinvent_scoring.scoring.score_components.pip.pip_log_prediction_component import PiPLogPredictionComponent
@@ -61,7 +62,10 @@ class ScoreComponentFactory:
             enum.RAT_PK_PIP: RatPKPiP,
             enum.CLAB_TOP_20: Top20,
             enum.RA_SCORE: PiPPredictionComponent,
-            enum.KPUU_PIP: PiPLogPredictionComponent
+            enum.KPUU_PIP: PiPLogPredictionComponent,
+            enum.LINKER_GRAPH_LENGTH: LinkerGraphLength,
+            enum.LINKER_EFFECTIVE_LENGTH: LinkerEffectiveLength,
+            enum.LINKER_LENGTH_RATIO: LinkerLengthRatio
         }
         return component_map
 
