@@ -9,7 +9,7 @@ from reinvent_scoring.scoring.score_summary import ComponentSummary
 class CustomAlerts(BaseScoreComponent):
     def __init__(self, parameters: ComponentParameters):
         super().__init__(parameters)
-        self._set_custom_alerts()
+        self.custom_alerts = self.parameters.specific_parameters.get(self.component_specific_parameters.SMILES, [''])
 
     def calculate_score(self, molecules: List) -> ComponentSummary:
         score = self._substructure_match(molecules, self.custom_alerts)
@@ -21,8 +21,3 @@ class CustomAlerts(BaseScoreComponent):
                       if Chem.MolFromSmarts(subst)]) for mol in query_mols]
         reverse = [1 - m for m in match]
         return reverse
-
-    def _set_custom_alerts(self):
-        self.custom_alerts = ['']
-        if len(self.parameters.smiles) > 0:
-            self.custom_alerts = self.parameters.smiles
