@@ -30,11 +30,13 @@ class PredictivePropertyComponent(BaseScoreComponent):
         try:
             activity_model = self._load_container(parameters)
         except:
-            raise Exception(f"The loaded file {parameters.model_path} isn't a valid scikit-learn model")
+            model_path = self.parameters.specific_parameters.get(self.component_specific_parameters.MODEL_PATH, "")
+            raise Exception(f"The loaded file `{model_path}` isn't a valid scikit-learn model")
         return activity_model
 
     def _load_container(self, parameters: ComponentParameters):
-        with open(parameters.model_path, "rb") as f:
+        model_path = self.parameters.specific_parameters.get(self.component_specific_parameters.MODEL_PATH, "")
+        with open(model_path, "rb") as f:
             scikit_model = pickle.load(f)
             packaged_model = ModelContainer(scikit_model, parameters.specific_parameters)
         return packaged_model
